.. currentmodule:: sardana.tango.pool

:mod:`~sardana.tango.pool`
==========================

.. automodule:: sardana.tango.pool

.. rubric:: Modules

.. toctree::
    :maxdepth: 1
    
    Pool <pool/Pool>
    PoolDevice <pool/PoolDevice>
    Controller <pool/Controller>
    Motor <pool/Motor>
    I/O register <pool/IORegister>
    Counter/Timer <pool/CTExpChannel>
    0D experiment channel <pool/ZeroDExpChannel>
    1D experiment channel <pool/OneDExpChannel>
    2D experiment channel <pool/TwoDExpChannel>
    PseudoMotor <pool/PseudoMotor>
    PseudoCounter <pool/PseudoCounter>
